# Nikas - Beta version

[![pipeline status](https://gitlab.com/nikas-project/Server/badges/master/pipeline.svg)](https://gitlab.com/nikas-project/Server/-/commits/master) [![Quality Gate Status](https://sonarcloud.io/api/project_badges/measure?project=Nikas-Project_Server&metric=alert_status)](https://sonarcloud.io/dashboard?id=Nikas-Project_Server) [![Lines of Code](https://sonarcloud.io/api/project_badges/measure?project=Nikas-Project_Server&metric=ncloc)](https://sonarcloud.io/dashboard?id=Nikas-Project_Server) [![Maintainability Rating](https://sonarcloud.io/api/project_badges/measure?project=Nikas-Project_Server&metric=sqale_rating)](https://sonarcloud.io/dashboard?id=Nikas-Project_Server) [![Security Rating](https://sonarcloud.io/api/project_badges/measure?project=Nikas-Project_Server&metric=security_rating)](https://sonarcloud.io/dashboard?id=Nikas-Project_Server)

The first persian comment system

- Python
- Self-Hosted
- Simple
